# Managing Fact Sheet Tags (GraphQL)
### On this page
  * [Adding Tags to a Fact Sheet](https://help.sap.com/docs/leanix/ea/managing-tags-on-fact-sheet#adding-tags-to-a-fact-sheet)
  * [Removing Tags from a Fact Sheet](https://help.sap.com/docs/leanix/ea/managing-tags-on-fact-sheet#removing-tags-from-a-fact-sheet)


Manage tags on a fact sheet using the GraphQL API.
Tags allow you to categorize fact sheets by attributes and relations that are not present in the standard configuration. For more information, see [Tags](https://help.sap.com/docs/leanix/ea/tags?locale=en-US&state=PRODUCTION&version=CLOUD "Tags are labels used to classify and categorize fact sheets, making it easy to filter, organize, and analyze data. Learn how to assign and manage tags, understand when and when not to use them, as well as leverage them for filtering and reporting.").
